@@ -9,25 +9,26 @@
 
 # import json
 # from re import search
-import time
-import json
+# import time
+# import json
+# from threading import Thread
 import traceback
 import shutil
 import os
 from pathlib import Path
-from threading import Thread
 import logging
-# import utils.string_utils as strUtils
+
 import ftputil
 from ftputil.error import FTPOSError
 import colemen_string_utils as strUtils
+import utils.file
 import utils.objectUtils as obj
 import utils.file_write as write
-import utils.file as f
+# import utils.file as f
 import utils.resources
 
+
 logger = logging.getLogger(__name__)
-_THREAD_GET_FILES_ARRAY = []
 
 
 def create(path, dir_name=False, **kwargs):
@@ -371,396 +372,6 @@ def get_folders_ftp(search_path=False, **kwargs):
     return dir_array
 
 
-def get_files(search_path=False, **kwargs):
-    '''
-        Get all files/data from the search_path.
-
-        ----------
-
-        Keyword Arguments
-        -----------------
-            [`search_path`=cwd] {str|list}
-                The search path or list of paths to iterate.
-
-            [`recursive`=True] {boolean}
-                If True the path is iterated recursively
-
-            [`ignore`=[]] {str|list}
-                A term or list or terms to ignore if the file path contains any of them.
-
-            [`extensions`=[]] {str|list}
-                An extension or list of extensions that the file must have.
-
-            [`threaded`=True] {bool}
-                if True, the process is multi-threaded,
-                this makes indexing much faster,
-                but it can easily overwhelm a cpu depending upon the drive.
-
-            `data_include` {str|list}
-                The data to get for each file, the shorter this list the faster it will complete.
-                By default it will get this:
-                    ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time',
-                    'modified_time', 'created_time', 'size']
-                so the list you provide will limit the amount of
-                reading/formatting needed to gather data.
-                Example:
-                    ['modified_time','size']  will take ~0.000129939 seconds per file on an SSD
-
-                    ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time',
-                    'modified_time', 'created_time', 'size']
-
-                    will take ~0.000173600 seconds per file on an SSD,
-                    it's not much but little things matter.. that's what she said.
-
-        return
-        ----------
-        `return` {list}
-            A list of dictionaries containing all matching files.
-    '''
-    file_array = []
-    if search_path is False:
-        search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
-    if isinstance(search_path, list) is False:
-        search_path = [search_path]
-
-    threaded = obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
-    recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-
-    data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
-    if isinstance(data_include, (str)):
-        data_include = [data_include]
-
-    # ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
-    exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
-    if isinstance(exclude, (str)):
-        exclude = [exclude]
-
-    include = obj.get_kwarg(['include'], [], (list, str), **kwargs)
-    if isinstance(include, (str)):
-        include = [include]
-
-    extension_array = strUtils.format.extension(
-        obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
-    if isinstance(extension_array, (str)):
-        extension_array = [extension_array]
-
-    if threaded is True:
-        for path in search_path:
-            gft = GetFilesThreaded(path, recursive=recursive, data_include=data_include,
-                                   exclude=exclude, include=include, extensions=extension_array)
-            return gft.master()
-    # print(json.dumps(extension_array, indent=4))
-    for path in search_path:
-        # pylint: disable=unused-variable
-        for root, folders, files in os.walk(path):
-            for file in files:
-                file_data = f.get_data(os.path.join(root, file), include=data_include)
-                if file_data is not None:
-                    # ignore = False
-                    # print(f"file_data['extension']: {file_data['extension']}")
-                    if len(exclude) > 0:
-                        if strUtils.parse.array_in_string(exclude, file_data['file_path']) is True:
-                            continue
-
-                    if len(include) > 0:
-                        if strUtils.parse.array_in_string(include, file_data['file_path']) is False:
-                            continue
-
-                    if len(extension_array) > 0:
-                        file_ext = strUtils.format.extension(file_data['extension'])
-                        if file_ext not in extension_array:
-                            continue
-
-                    # if len(ignore_array) > 0:
-                    #     for ignore_string in ignore_array:
-                    #         if ignore_string in file_data['file_path']:
-                    #             ignore = True
-
-                    # if ignore is False:
-                        # fd['file_hash'] = generateFileHash(fd['file_path'])
-                    file_array.append(file_data)
-
-            if recursive is False:
-                break
-        return file_array
-        # path_files = index_files(path, extension_array, ignore_array, recursive)
-        # file_array = path_files + file_array
-    return file_array
-
-
-class GetFilesThreaded:
-    '''
-        A class implementation of the get_files method.
-        This allows it use threading.
-    '''
-
-    def __init__(self, search_path, **kwargs):
-        self.threads = []
-        self.file_array = []
-        self.max_threads = 20
-        self.search_path = search_path
-
-        if search_path is False:
-            self.search_path = obj.get_kwarg(
-                ['search path', 'search'], os.getcwd(), (str, list), **kwargs)
-        if isinstance(self.search_path, list) is False:
-            self.search_path = [self.search_path]
-
-        self.recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-
-        self.data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
-        if isinstance(self.data_include, (str)):
-            self.data_include = [self.data_include]
-
-        # ignore_array = obj.get_kwarg(
-            # ['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
-        self.exclude = obj.get_kwarg(
-            ['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
-        if isinstance(self.exclude, (str)):
-            self.exclude = [self.exclude]
-
-        self.include = obj.get_kwarg(['include'], [], (list, str), **kwargs)
-        if isinstance(self.include, (str)):
-            self.include = [self.include]
-
-        self.extension_array = strUtils.format.extension(
-            obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
-        if isinstance(self.extension_array, (str)):
-            self.extension_array = [self.extension_array]
-
-    def remove_thread_by_id(self, thread_id):
-        '''
-            Removes an active thread from self.threads
-
-            ----------
-
-            Arguments
-            -------------------------
-            `thread_id` {str}
-                The id of the thread to remove
-
-            Meta
-            ----------
-            `author`: Colemen Atwood
-            `created`: 12-19-2021 13:48:58
-            `memberOf`: dir
-            `version`: 1.0
-            `method_name`: remove_thread_by_id
-        '''
-        threads = self.threads
-        new_threads = []
-        for thread in threads:
-            if thread != thread_id:
-                new_threads.append(thread)
-        self.threads = new_threads
-
-    def _get_data_thread(self, file_path):
-        file_data = f.get_data(file_path, data_include=self.data_include)
-        if file_data is not None:
-            # ignore = False
-            # print(f"file_data['extension']: {file_data['extension']}")
-            if len(self.exclude) > 0:
-                if strUtils.parse.array_in_string(self.exclude, file_data['file_path']) is True:
-                    return
-
-            if len(self.include) > 0:
-                if strUtils.parse.array_in_string(self.include, file_data['file_path']) is False:
-                    return
-
-            if len(self.extension_array) > 0:
-                file_ext = strUtils.format.extension(file_data['extension'])
-                if file_ext not in self.extension_array:
-                    return
-
-        self.file_array.append(file_data)
-
-    def single_file_thread(self, data):
-        '''
-            Executes the get_data function on an array of files in a separate thread
-            and removes itself from self.threads once completed.
-
-            ----------
-
-            Arguments
-            -------------------------
-            `data` {dict}
-                a dictionary containing the file_paths and thread_id keys
-
-            Meta
-            ----------
-            `author`: Colemen Atwood
-            `created`: 12-19-2021 13:49:59
-            `memberOf`: dir
-            `version`: 1.0
-            `method_name`: single_file_thread
-        '''
-        file_paths = data['file_paths']
-        for file_path in file_paths:
-            self._get_data_thread(file_path)
-        self.remove_thread_by_id(data['thread_id'])
-
-    def master(self):
-        '''
-            Executes the get files process using threads
-
-            ----------
-
-            Return {list}
-            ----------------------
-            A list of files found in the search_path.
-
-            Meta
-            ----------
-            `author`: Colemen Atwood
-            `created`: 12-19-2021 13:52:24
-            `memberOf`: dir
-            `version`: 1.0
-            `method_name`: master
-        '''
-        for path in self.search_path:
-            # pylint: disable=unused-variable
-            for root, folders, files in os.walk(path):
-
-                # print(f"Active Threads: {csu.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
-                while len(self.threads) >= self.max_threads:
-                    time.sleep(.1)
-
-                file_paths = [os.path.join(root, x) for x in files]
-                data = {
-                    "thread_id": strUtils.gen.hash(json.dumps(file_paths)),
-                    "file_paths": file_paths
-                }
-                thread = Thread(target=self.single_file_thread, args=(data,))
-                self.threads.append(data['thread_id'])
-                thread.start()
-
-                if self.recursive is False:
-                    break
-            # return self.file_array
-            # path_files = index_files(path, extension_array, ignore_array, recursive)
-            # file_array = path_files + file_array
-        # print(f"                                                                                                                      ", end="\r", flush=True)
-        return self.file_array
-
-        # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
-        #     '''
-        #         Get all files/data from the search_path.
-
-        #         ----------
-        #         Keyword Arguments
-        #         -----------------
-
-        #             `search_path`=cwd {str|list}
-        #                 The search path or list of paths to iterate.
-        #             `recursive`=True {boolean}
-        #                 If True the path is iterated recursively
-        #             `ignore`=[] {str|list}
-        #                 A term or list or terms to ignore if the file path contains any of them.
-        #             `extensions`=[] {str|list}
-        #                 An extension or list of extensions that the file must have.
-
-        #         return
-        #         ----------
-        #         `return` {str}
-        #             A list of dictionaries containing all matching files.
-        #     '''
-        #     global _THREAD_GET_FILES_ARRAY
-        #     if exclude is None:
-        #         exclude = []
-        #     if include is None:
-        #         include = []
-        #     if extensions is None:
-        #         extensions = []
-        #     if data_include is None:
-        #         data_include = []
-        #     for path in search_path:
-        #         print(f"Files indexed: {len(_THREAD_GET_FILES_ARRAY)}", end="\r", flush=True)
-        #         _THREAD_GET_FILES_ARRAY = _THREAD_GET_FILES_ARRAY + get_files(search_path=path, recursive=recursive, exclude=exclude, include=include, extensions=extensions, data_include=data_include)
-        #     # _THREAD_GET_FILES_ARRAY = _THREAD_GET_FILES_ARRAY + get_files(search_path=search_path, recursive=recursive, exclude=exclude, include=include, extensions=extensions)
-        #     return
-
-        # def get_files_thread(search_path=False, **kwargs):
-        #     '''
-        #         Get all files/data from the search_path.
-
-        #         ----------
-        #         Keyword Arguments
-        #         -----------------
-
-        #             `search_path`=cwd {str|list}
-        #                 The search path or list of paths to iterate.
-        #             `recursive`=True {boolean}
-        #                 If True the path is iterated recursively
-        #             `ignore`=[] {str|list}
-        #                 A term or list or terms to ignore if the file path contains any of them.
-        #             `extensions`=[] {str|list}
-        #                 An extension or list of extensions that the file must have.
-
-        #         return
-        #         ----------
-        #         `return` {str}
-        #             A list of dictionaries containing all matching files.
-        #     '''
-        #     global _THREAD_GET_FILES_ARRAY
-        #     _THREAD_GET_FILES_ARRAY = []
-
-        #     file_array = []
-        #     if search_path is False:
-        #         search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
-        #     if isinstance(search_path, list) is False:
-        #         search_path = [search_path]
-
-        #     data_include = obj.get_kwarg(['data include'], [], (list, str), **kwargs)
-        #     if isinstance(data_include, (str)):
-        #         data_include = [data_include]
-
-        #     recursive = obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
-
-        #     # ignore_array = obj.get_kwarg(['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
-        #     exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
-        #     if isinstance(exclude, (str)):
-        #         exclude = [exclude]
-
-        #     include = obj.get_kwarg(['include'], [], (list, str), **kwargs)
-        #     if isinstance(include, (str)):
-        #         include = [include]
-
-        #     extension_array = strUtils.format.extension(obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
-        #     if isinstance(extension_array, (str)):
-        #         extension_array = [extension_array]
-
-        #     dir_array = get_folders(search_path, recursive=recursive, exclude=exclude, include=include, paths_only=True)
-        #     # dir_array.append(search_path)
-        #     max_threads = 30
-        #     dirs_per_thread = round(len(dir_array) / max_threads)
-        #     print(f"dirs_per_thread: {dirs_per_thread}")
-        #     threads = []
-        #     for idx in range(max_threads):
-        #         min_id = idx * dirs_per_thread
-        #         max_id = min_id + dirs_per_thread
-        #         if max_id > len(dir_array):
-        #             max_id = len(dir_array)
-
-        #         search_paths = dir_array[min_id:max_id]
-        #         print(f"Thread {idx} [{min_id}:{max_id}]")
-        #         threads.append(Thread(target=_get_files_single_thread, args=(search_paths, recursive, exclude, include, data_include)))
-
-        #         # file_array = get_files(search_paths, recursive=recursive, exclude=exclude, include=include)
-        #         # file_array += get_files(search_paths, recursive=recursive, exclude=exclude, include=include)
-        #     for thread in threads:
-        #         thread.start()
-        #     for thread in threads:
-        #         thread.join()
-        #         # print(f"result: {result}")
-        #     return _THREAD_GET_FILES_ARRAY
-        #     # print(f"dir_array")
-        #     # print(json.dumps(dir_array, indent=4))
-        #     # print(f"_THREAD_GET_FILES_ARRAY")
-        #     # print(json.dumps(_THREAD_GET_FILES_ARRAY, indent=4))
-
-        #     # print(f"Total files indexed: {len(file_array)}")
-
-
 def index_files(start_path, extension_array=None, ignore_array=None, recursive=True):
     '''
         Iterates the start_path to find all files within.
@@ -791,7 +402,7 @@ def index_files(start_path, extension_array=None, ignore_array=None, recursive=T
     # pylint: disable=unused-variable
     for root, folders, files in os.walk(start_path):
         for file in files:
-            file_data = f.get_data(os.path.join(root, file))
+            file_data = file.get_data(os.path.join(root, file))
             ignore = False
 
             if len(extension_array) > 0:
@@ -1045,8 +656,8 @@ def mirror(src, dst, **kwargs):
         try:
             os.makedirs(folder['dst_path'], exist_ok=True)
             if dirs_only is False:
-                files = get_files(search_path=folder['file_path'], include=include_files,
-                                  exclude=exclude_files, recursive=False)
+                files = file.get_files(search_path=folder['file_path'], include=include_files,
+                                       exclude=exclude_files, recursive=False)
                 # newlist = [x['dst_path'] = x['file_path'].replace(src, dst) for x in files]
                 for file in files:
                     file['src_path'] = file['file_path']
@@ -1056,7 +667,7 @@ def mirror(src, dst, **kwargs):
                     for file in files:
                         write.write(file['dst_path'], "EMPTY TEST FILE CONTENT")
                 else:
-                    f.copy(files)
+                    file.copy(files)
         except:
             # print(f"{traceback.format_exc()}")
             logger.warning("failed to create directory: %s", folder["dst_path"])
@@ -1157,13 +768,13 @@ def mirror_to_server(src, dst, **kwargs):
         try:
             create(folder['dst_path'], ftp=ftp)
             if dirs_only is False:
-                files = get_files(search_path=folder['file_path'], include=include_files,
-                                  exclude=exclude_files, recursive=False, ftp=ftp)
+                files = file.get_files(search_path=folder['file_path'], include=include_files,
+                                       exclude=exclude_files, recursive=False, ftp=ftp)
                 # newlist = [x['dst_path'] = x['file_path'].replace(src, dst) for x in files]
                 for file in files:
                     file['src_path'] = file['file_path']
                     file['dst_path'] = file['file_path'].replace(src, dst)
-                f.copy(files, ftp=ftp)
+                file.copy(files, ftp=ftp)
         except:
             logger.warning("failed to create directory: %s", folder["dst_path"])
             logger.warning(traceback.format_exc())
